@@ -1,5 +1,7 @@
-from circle.resources.abstract import RetrievableAPIResource
-from circle.resources.abstract import ListableAPIResource
+from circle.resources.abstract import (
+    ListableAPIResource,
+    RetrievableAPIResource
+)
 
 
 class PublicKey(ListableAPIResource):
